@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 use Carp ();
 use Scalar::Util ();
@@ -198,6 +198,19 @@ sub is_same_interface_inlined {
     return join "\n && ", @src;
 }
 
+sub display {
+    my $self = shift;
+
+    my $s = '';
+    $s .= $self->invocant->display . ': '
+        if $self->invocant && $self->invocant->display;
+
+    $s .= join ', ', map { $_->display } @{$self->args};
+    $s .= ', ' if $s && $self->slurpy;
+    $s .= $self->slurpy->display if $self->slurpy;
+    return $s;
+}
+
 1;
 __END__
 
@@ -375,17 +388,33 @@ This is computed as follows:
   If there are any named or slurpy parameters, the result is Inf.
   Otherwise the result is the number of all invocants and positional parameters.
 
+=head2 METHODS
+
 =head3 is_same_interface($other_meta)
 
 A boolean value indicating whether C<Sub::Meta::Parameters> object is same or not.
 Specifically, check whether C<args>, C<nshift> and C<slurpy> are equal.
 
-=head2 OTHERS
-
 =head3 is_same_interface_inlined($other_meta_inlined)
 
 Returns inlined C<is_same_interface> string.
 
+=head3 display
+
+Returns the display of Sub::Meta::Parameters:
+
+    use Sub::Meta::Parameters;
+    use Types::Standard qw(Num);
+    my $meta = Sub::Meta::Parameters->new(
+        args => [
+            { name => '$lat', type => Num, named => 1 },
+            { name => '$lng', type => Num, named => 1 },
+        ],
+    );
+    $meta->display; # 'Num :$lat, Num :$lng'
+
+=head2 OTHERS
+
 =head3 param_class
 
 Returns class name of param. default: Sub::Meta::Param
